pub enum RetryMessage {
Retry,
Continue,
End,
Complete,
}Variants
Retry
Starts the retry cycle. Later Retry messages are ignored.
Continue
Internal scheduled retry attempt after the cycle has already started.
End
Explicitly finishes the retry cycle.
Complete
Internal completion marker used to stop after the final target delivery had a chance to run.