NotPersistentActor

Trait NotPersistentActor 

pub trait NotPersistentActor { }
Marker trait for actors that do not use persistence.

Implement this on your actor to allow passing it directly to create_root_actor or create_child. Persistent actors use PersistentActor::initial() instead and must NOT also implement this trait.

Implementors