pub trait Message:
Clone
+ Send
+ Sync
+ 'static {
// Provided method
fn is_critical(&self) -> bool { ... }
}Expand description
Defines the type of value an actor receives as a message.
Provided Methods
Sourcefn is_critical(&self) -> bool
fn is_critical(&self) -> bool
Returns true if this message must be processed before the actor stops; defaults to false.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.